Attribute VB_Name = "mdAPI"

Option Explicit
'IDRISI's map related functions and constant declarations for IDRISI API

  Global Const PROCSTATUS_ACTIVE = 1
  Global Const PROCSTATUS_NORMAL_TERMINATE = 2
  Global Const PROCSTATUS_ERROR_TERMINATE = 3

  Global Const REPORT_TYPE_WORKING = 1
  Global Const REPORT_TYPE_PERCENTDONE = 2
  Global Const REPORT_TYPE_PASS_X_OF_N = 3
  Global Const REPORT_TYPE_PASS_TOTALUNKNOWN = 4
  Global Const REPORT_TYPE_COMPLEXPASS = 5

  Global Const MONITOR_FROM_CLIENT_ONLY = 0
  Global Const MONITOR_FROM_IDRISI = 1

  Global Const DISPLAY_TYPE_IMAGE = 0
  Global Const DISPLAY_TYPE_VECTOR = 1
  Global Const DISPLAY_TYPE_COMP = 2

  Global Const SHOW_IDRISI_HIDDEN = 0             '= Windows API SW_HIDE
  Global Const SHOW_IDRISI_NORMAL = 1             '= Windows API SW_SHOWNORMAL
  Global Const SHOW_IDRISI_MINIMIZED = 2          '= Windows API SW_SHOWMINIMIZED}
  Global Const SHOW_IDRISI_MAXIMIZED = 3          '= Windows API SW_SHOWMAXIMIZED -- the IDRISI default state}

  Global Const DEBUG_MODE_OFF = 0
  Global Const DEBUG_MODE_ON = 1
  
  Global Const DATA_TYPE_INTEGER = 0
  Global Const DATA_TYPE_REAL = 1
  Global Const DATA_TYPE_BYTE = 2
  Global Const FILE_TYPE_ASCII = 0
  Global Const FILE_TYPE_BINARY = 1
  Global Const FILE_TYPE_PACKED = 2

  Global Const OBJ_TYPE_POINT = 0
  Global Const OBJ_TYPE_LINE = 1
  Global Const OBJ_TYPE_POLYGON = 2
  Global Const OBJ_TYPE_ARC = 3
  Global Const OBJ_TYPE_COVERAGE = 4
  Global Const OBJ_TYPE_TEXT = 6
  Global Const OBJ_TYPE_UNKNOWN = 999

  '{type declarations for IDRISI API}
 
 Public Type ProgStruct
    Status         As Integer
    ReportType     As Integer
    PassNum        As Integer
    TotalPasses    As Integer
    PercentDone    As Single
    ErrorCode      As Integer
    ErrorFile As String * 255 'Char
    ErrorMessage As String * 255 'Char
    SubstString1 As String * 255 'Char
    SubstString2 As String * 255 'Char
  End Type

 Global lpProgStruct As ProgStruct
 Global prgstProg As ProgStruct 'reusable variable
 Global lpInteger As Integer
 
 Type ImageDoc
    title As String * 256 ' array [0..255] of char;
    datatype       As Integer 'smallint;
    FileType       As Integer ': smallint;
    Cols           As Single ': integer;
    Rows           As Single ' integer;
    refsystem As String * 256
    refunits As String * 256  '      : array [0..255] of char;
    UnitDistance   As Single
    minX           As Single
    maxX           As Single
    minY           As Single
    maxY           As Single
    posnerror As String * 256 '     : array[0..255] of char;
    resolution As String * 256 '     : array[0..255] of char;
    minvalue       As Single
    maxvalue       As Single
    valunits As String * 256 ' array [0..255] of char;
    valerror As String * 256
    flagvalue As String * 256 '      : array [0..255] of char;
    flagdefn As String * 256 '       : array [0..255] of char;
    LegendCats As Integer '    : smallint;
   ' Legend(0 To 255) As String '         : array [0..255] of Pchar;
End Type

Global lpImageDoc As ImageDoc

 Type VectorDoc
     title As String * 255 'as array[0..255] of char;
     datatype    As Integer
     FileType  As Integer ' smallint;
     objtype   As Integer ' smallint;
     refsystem As String * 255 ' : array[0..255] of char;
     refunits As String * 255 '  : array[0..255] of char;
     unitdist  As Single
     minX      As Single
     maxX      As Single
     minY      As Single
     maxY      As Single
     posnerror As String * 255 ' : array[0..255] of char;
     resolution As String * 255 ': array[0..255] of char;
End Type
Global lpVectorDoc As VectorDoc


Type FieldDoc
     fieldname As String * 255 ' : array[0..255] of char;
     datatype As Integer ' smallint;
     format As Integer ': smallint;
End Type

Type ValuesDoc
     title As String * 255 '     : array[0..255] of char;
     FileType  As Integer
     records   As Integer ' smallint;
     numfields As Integer ': smallint;
     field As String * 255 '     : array[0..1] of FieldDoc;
     minvalue  As Single
     maxvalue  As Single
     valunits As String * 255 '  : array[0..255] of char;
     valerror As String * 255 '  : array[0..255] of char;
     flagvalue As String * 255 ' : array[0..255] of char;
     flagdefn As String * 255 '  : array[0..255] of char;
     LegendCats As Integer ' smallint;
    ' Legend(0 To 255) As String
End Type

Global lpValuesDoc As ValuesDoc

Type EnvDoc
     img_file_extension As String * 5
     imgdoc_file_extension As String * 5
     vec_file_extension As String * 5
     vecdoc_file_extension As String * 5
     val_file_extension As String * 5
     valdoc_file_extension As String * 5
End Type

Global lpEnvDoc As EnvDoc
 
 
'{function declarations for IDRISI API}

Declare Function GetIdrisiDirectory Lib "mercur32" (ByVal IdrDir As String) As Integer
Declare Function GetIdrisiLanguage Lib "mercur32" (ByVal IdrLang As String) As Integer
Declare Function IsIdrisiPresent Lib "mercur32" () As Integer '0 = no
Declare Function GetIdrisiHwnd Lib "mercur32" () As Integer
Declare Function LaunchIdrisi Lib "mercur32" (ByVal CmdShow As Integer) As Integer
Declare Function CloseIdrisi Lib "mercur32" () As Integer
Declare Function GetDataDirectory Lib "mercur32" (ByVal DataDir As String) As Integer
Declare Function SetDataDirectory Lib "mercur32" (ByVal NewDataDir As String) As Integer
Declare Function RegisterClient Lib "mercur32" () As Integer
Declare Function UnRegisterClient Lib "mercur32" (ByVal ClientId As Integer) As Integer
Declare Function LaunchModule Lib "mercur32" (ByVal ClientId As Integer, ByVal ClientOptions As Integer, ByVal ModName As String, ByVal Cmdln As String, ByVal OutputTitle As String, ByVal OutputUnits As String, PtHinst As Integer) As Integer
Declare Function InitProgressTracking Lib "mercur32" (ClientId As Integer, ByVal procname As String) As Integer
Declare Function GetProgress Lib "mercur32" (ByVal ClientId As Integer, ByVal ProcId As Integer, ByRef Prog As ProgStruct) As Integer
Declare Function SetProgress Lib "mercur32" (ByVal ClientId As Integer, ByVal ProcId As Integer, ByRef Prog As ProgStruct) As Integer
Declare Function DisplayComposition Lib "mercur32" (ByVal ClientId As Integer, ByVal DispType As Integer, ByVal fname As String, ByVal PalName As String) As Integer
Declare Function SetDebugMode Lib "mercur32" (mode As Integer) As Integer
Declare Function Read_DocFile Lib "mercur32" (ByVal fname As String, ByRef Doc As ImageDoc) As Integer  '; export; stdcall;'
Declare Function Create_DocFile Lib "mercur32" (ByVal fname As String, ByRef Doc As ImageDoc) As Integer  '; export; stdcall;
Declare Function Create_Vec_Docfile Lib "mercur32" (ByVal fname As String, ByRef Doc As VectorDoc) As Integer '; export; stdcall;
Declare Function Read_Vec_Docfile Lib "mercur32" (ByVal fname As String, ByRef Doc As VectorDoc) As Integer ' smallint; export; stdcall;
Declare Function Create_Val_Docfile Lib "mercur32" (ByVal fname As String, ByRef Doc As ValuesDoc) As Integer '; export; stdcall;
Declare Function Read_Val_Docfile Lib "mercur32" (ByVal fname As String, ByRef Doc As ValuesDoc) As Integer ' smallint; export; stdcall;
Declare Function Read_Legend Lib "mercur32" (ByVal fname As String, ByVal FileType As Integer, ByVal LegendCat As Integer, ByVal LegendText As String) As Integer
Declare Function Add_Legend Lib "mercur32" (ByVal fname As String, ByVal FileType As Integer, ByVal LegendCat As Integer, ByVal LegendText As String) As Integer

Declare Function GetIdrisiExtensions Lib "mercur32" (Env As EnvDoc) As Integer '; export; stdcall;
Declare Function SetIdrisiExtensions Lib "mercur32" (Env As EnvDoc) As Integer  ' smallint; export; stdcall;
'end of Idrisi API declarations


'Inserted
Function fnAddNull(strIn As String) As String
'Created to add null chars to satisfy idrisi's length for a 255-char null-terminated
'string for its data directory etc.
Dim intLength As Integer
intLength = Len(strIn)

Select Case intLength
Case Is > 255
    Err.Raise gMinor, , "Error, IDRISI data directory supplied is longer than 255 characters"
    Exit Function
Case Is = 255
    fnAddNull = strIn
Case Else
    For i = 1 To (255 - intLength)
        strIn = strIn & Chr$(0)
    Next i
    fnAddNull = strIn
End Select
Exit Function

End Function

Function fnWait(intClientID As Integer, intRetCode As Integer, prgstProg As ProgStruct)
'Wait until module is finished (before unregistering client or doing owt else).

Dim intStatus As Integer
On Error GoTo err_Wait
intStatus = PROCSTATUS_ACTIVE ': fmAmaz.pbB = 0: fmAmaz.pbB.Visible = True
While intStatus = PROCSTATUS_ACTIVE
    intStatus = GetProgress(intClientID, intRetCode, prgstProg)
    ''GetProgress returns 'Status': either 1,2,3 (run,finish,crash)
    Select Case prgstProg.ReportType
        Case REPORT_TYPE_PERCENTDONE
            'fmAmaz.pbB = prgstProg.PercentDone
        Case REPORT_TYPE_WORKING
        '
        Case REPORT_TYPE_PASS_X_OF_N Or REPORT_TYPE_COMPLEXPASS
            'fmAmaz.pbB = prgstProg.PassNum / prgstProg.TotalPasses
        Case REPORT_TYPE_PASS_TOTALUNKNOWN
        '
    End Select
'fmAmaz.pbB.Refresh
Wend
'fmAmaz.pbB.Visible = False: fmAmaz.pbB = 0
Exit Function
err_Wait:
MsgBox "Error: " & Err.Description & ". Error No:" & Err.Number
Exit Function
End Function
